
.listing_status {
    float: left;
    margin: 4px 8px 4px 4px;
}
.listing_main_context {
    font-size: 120%;
}
.listing .listing_col2_context {
   text-align: center; 
}
.listing .listing_col2 {
    width: 10%;
    text-align: center;
}
.listing .listing_col3 {
    width: 25%;
    text-align: center;
}
#forum-posts table,
#forum-topics table,
#forum-subforums table {
    width: 100%;
    clear: both;
}
#forum-topics table.listing th,
#forum-subforums table.listing th {
    padding: 0.5em 0.5em;
}
#forum-posts, 
#forum-topics {
    margin: 2em 0 0 0;
}
#forum-posts .context,
#forum-topics .context {
    background-position: 7px 6px;
    font-size: 10px;
    padding: 3px 4px 3px 16px;
}
#forum-posts .forum-actions,
#forum-topics .forum-actions {
    list-style-image: none;
    list-style-type: none;
    margin: 0px;
    float: left;
}
#forum-posts .forum-actions li,
#forum-posts .forum-actions form,
#forum-topics .forum-actions li,
#forum-topics .forum-actions form {
    display: block;
    float: left;
    margin-right: 0.5em;
}
.forum-posts-batch .listingBar {
    background: none;
    border: 0;
    margin: 0;
    font-size: 9px;
    clear: none;
    margin: 0;
    padding: 1em 1em;
}



#forum-subforums .listing .listing_col1 {
    width: 65%;
    text-align: center;
}


#forum-subforums .listing .listing_col1 {
    width: 55%;
}


#forum-posts table {
    border-top: 1px solid #8CACBB;
}
#forum-posts .listing_col1_context {
    width: 25%;
}
#forum-posts .listing_col2_context {
    width: 75%;
    text-align: left;
}
